#  -*- coding: UTF-8 -*-
# OpenCV获取摄像头画面后传递给unihiker库显示到屏幕上，同时屏幕叠加显示板载光线传感器值
# 注意unihiker库需要升级到0.0.25.2及以上版本，否则可能会报'str' object has no attribute 'read'错误
import cv2
from PIL import Image
from unihiker import GUI
from pinpong.board import Board,Pin
from pinpong.extension.unihiker import *

# 载入预训练的人脸检测模型，这里使用的是Haar特征分类器
face_cascade = cv2.CascadeClassifier(cv2.data.haarcascades + 'haarcascade_frontalface_default.xml')

u_gui=GUI()
Board().begin()
#打开摄像头
vd = cv2.VideoCapture(0)
# 设置视频捕获属性
vd.set(cv2.CAP_PROP_FRAME_WIDTH, 120)
vd.set(cv2.CAP_PROP_FRAME_HEIGHT, 160)
vd.set(cv2.CAP_PROP_BUFFERSIZE, 1)

# 检查设置是否成功
frame_width = vd.get(cv2.CAP_PROP_FRAME_WIDTH)
frame_height = vd.get(cv2.CAP_PROP_FRAME_HEIGHT)
buffer_size = vd.get(cv2.CAP_PROP_BUFFERSIZE)

print(f"Frame Width: {frame_width}, Frame Height: {frame_height}, Buffer Size: {buffer_size}")

bgImg=u_gui.draw_image(image="",x=0,y=0)
ltTxt=u_gui.draw_text(text="行空板",x=10,y=10,font_size=28, color="#00FF00")

while True:
    ret, img = vd.read()
     # 进行左右对称
    #img = cv2.resize(img, (240, 320)) # 调整图像尺寸与行空板相同
    img = cv2.flip(img, 1)
    #img = cv2.rotate(img,cv2.ROTATE_90_CLOCKWISE) #旋转90度

    
    # 将图像转换为灰度图，因为人脸检测通常在灰度图上进行
    gray = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)

    # 检测图像中的人脸
    faces = face_cascade.detectMultiScale(gray, scaleFactor=1.1, minNeighbors=5, minSize=(30, 30), flags=cv2.CASCADE_SCALE_IMAGE)

    # 在检测到的人脸周围画矩形框
    for (x, y, w, h) in faces:
        cv2.rectangle(img, (x, y), (x+w, y+h), (255, 0, 0), 2)


    img= Image.fromarray(cv2.cvtColor(img, cv2.COLOR_BGR2RGB)) #将opecv图片格式转化为unihiker库图片格式
    bgImg.config(image=img)
    ltTxt.config(text=(str(light.read())))